
USE [Credit];
GO

-- Modifying the Credit data to set up the scenario
UPDATE  [dbo].[member]
SET     [city] = 'Minneapolis',
        [state_prov] = 'MN'
WHERE   [member_no] % 10 = 0;
UPDATE  [dbo].[member]
SET     [city] = 'New York',
        [state_prov] = 'NY'
WHERE   [member_no] % 10 = 1;
UPDATE  [dbo].[member]
SET     [city] = 'Chicago',
        [state_prov] = 'IL'
WHERE   [member_no] % 10 = 2;
UPDATE  [dbo].[member]
SET     [city] = 'Houston',
        [state_prov] = 'TX'
WHERE   [member_no] % 10 = 3;
UPDATE  [dbo].[member]
SET     [city] = 'Philadelphia',
        [state_prov] = 'PA'
WHERE   [member_no] % 10 = 4;
UPDATE  [dbo].[member]
SET     [city] = 'Phoenix',
        [state_prov] = 'AZ'
WHERE   [member_no] % 10 = 5;
UPDATE  [dbo].[member]
SET     [city] = 'San Antonio',
        [state_prov] = 'TX'
WHERE   [member_no] % 10 = 6;
UPDATE  [dbo].[member]
SET     [city] = 'San Diego',
        [state_prov] = 'CA'
WHERE   [member_no] % 10 = 7;
UPDATE  [dbo].[member]
SET     [city] = 'Dallas',
        [state_prov] = 'TX'
WHERE   [member_no] % 10 = 8;
GO

--So let's look at the cardinality estimate for a specific operator in the following query 
--(using RECOMPILE to get fresh query_optimizer_estimate_cardinality events on each execution):
SELECT  m.[lastname],
        m.[firstname],
        SUM(c.[charge_amt]) AS [Total_Charge_amt]
FROM    [dbo].[member] AS [m]
INNER JOIN [dbo].[charge] AS [c] ON
    m.[member_no] = c.[member_no]
WHERE   [city] = 'Minneapolis' AND
        [state_prov] = 'MN'
GROUP BY m.[lastname],
        m.[firstname]
OPTION (RECOMPILE);
GO

SELECT  m.[lastname],
        m.[firstname],
        SUM(c.[charge_amt]) AS [Total_Charge_amt]
FROM    [dbo].[member] AS [m]
INNER JOIN [dbo].[charge] AS [c] ON
    m.[member_no] = c.[member_no]
WHERE   [city] = 'Minneapolis' AND
        [state_prov] = 'MN'
GROUP BY m.[lastname],
        m.[firstname]
OPTION (RECOMPILE, QUERYTRACEON 9481);
GO

-- add column for 3-predicate estimate
ALTER TABLE [dbo].[member]
ADD [county] varchar(15) NULL;

-- And then next I'll revise my previous city/state update script to include county:
UPDATE  [dbo].[member]
SET     [city] = 'Minneapolis',
        [state_prov] = 'MN',
        [county] = 'Hennepin'
WHERE   [member_no] % 10 = 0;
UPDATE  [dbo].[member]
SET     [city] = 'New York',
        [state_prov] = 'NY',
        [county]='Manhattan'
WHERE   [member_no] % 10 = 1;
UPDATE  [dbo].[member]
SET     [city] = 'Chicago',
        [state_prov] = 'IL',
        [county]='Cook'
WHERE   [member_no] % 10 = 2;
UPDATE  [dbo].[member]
SET     [city] = 'Houston',
        [state_prov] = 'TX',
        [county]='Harrisburg'
WHERE   [member_no] % 10 = 3;
UPDATE  [dbo].[member]
SET     [city] = 'Philadelphia',
        [state_prov] = 'PA',
        [county]='Philadelphia'
WHERE   [member_no] % 10 = 4;
UPDATE  [dbo].[member]
SET     [city] = 'Phoenix',
        [state_prov] = 'AZ',
        [county]=''
WHERE   [member_no] % 10 = 5;
UPDATE  [dbo].[member]
SET     [city] = 'San Antonio',
        [state_prov] = 'TX',
        [county]='Bexar'
WHERE   [member_no] % 10 = 6;
UPDATE  [dbo].[member]
SET     [city] = 'San Diego',
        [state_prov] = 'CA',
        [county]='San Diego'
WHERE   [member_no] % 10 = 7;
UPDATE  [dbo].[member]
SET     [city] = 'Dallas',
        [state_prov] = 'TX',
        [county]='Dallas'
WHERE   [member_no] % 10 = 8;
GO

SELECT  m.[lastname],
        m.[firstname],
        SUM(c.[charge_amt]) AS [Total_Charge_amt]
FROM    [dbo].[member] AS [m]
INNER JOIN [dbo].[charge] AS [c] ON
    m.[member_no] = c.[member_no]
WHERE   [city] = 'Minneapolis' AND
        [state_prov] = 'MN' AND
        [county] = 'Hennepin'
GROUP BY m.[lastname],
        m.[firstname]
OPTION (RECOMPILE);
GO
